From 9e51e4e52ae565503934c97c84ee5a7d9bcb2dcc Mon Sep 17 00:00:00 2001
From: Peter Eisentraut <peter_e@gmx.net>
Date: Thu, 21 Sep 2017 14:42:10 -0400
Subject: [PATCH] Fix build with !USE_WIDE_UPPER_LOWER

The placement of the ifdef blocks in formatting.c was pretty bogus, so
the code failed to compile if USE_WIDE_UPPER_LOWER was not defined.
---
 src/backend/utils/adt/formatting.c | 12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/src/backend/utils/adt/formatting.c b/src/backend/utils/adt/formatting.c
index 46f45f6654..2bf484cda3 100644
--- a/src/backend/utils/adt/formatting.c
+++ b/src/backend/utils/adt/formatting.c
@@ -1528,7 +1528,6 @@ str_tolower(const char *buff, size_t nbytes, Oid collid)
 	{
 		result = asc_tolower(buff, nbytes);
 	}
-#ifdef USE_WIDE_UPPER_LOWER
 	else
 	{
 		pg_locale_t mylocale = 0;
@@ -1566,6 +1565,7 @@ str_tolower(const char *buff, size_t nbytes, Oid collid)
 		else
 #endif
 		{
+#ifdef USE_WIDE_UPPER_LOWER
 			if (pg_database_encoding_max_length() > 1)
 			{
 				wchar_t    *workspace;
@@ -1603,8 +1603,8 @@ str_tolower(const char *buff, size_t nbytes, Oid collid)
 				wchar2char(result, workspace, result_size, mylocale);
 				pfree(workspace);
 			}
-#endif							/* USE_WIDE_UPPER_LOWER */
 			else
+#endif							/* USE_WIDE_UPPER_LOWER */
 			{
 				char	   *p;
 
@@ -1652,7 +1652,6 @@ str_toupper(const char *buff, size_t nbytes, Oid collid)
 	{
 		result = asc_toupper(buff, nbytes);
 	}
-#ifdef USE_WIDE_UPPER_LOWER
 	else
 	{
 		pg_locale_t mylocale = 0;
@@ -1690,6 +1689,7 @@ str_toupper(const char *buff, size_t nbytes, Oid collid)
 		else
 #endif
 		{
+#ifdef USE_WIDE_UPPER_LOWER
 			if (pg_database_encoding_max_length() > 1)
 			{
 				wchar_t    *workspace;
@@ -1727,8 +1727,8 @@ str_toupper(const char *buff, size_t nbytes, Oid collid)
 				wchar2char(result, workspace, result_size, mylocale);
 				pfree(workspace);
 			}
-#endif							/* USE_WIDE_UPPER_LOWER */
 			else
+#endif							/* USE_WIDE_UPPER_LOWER */
 			{
 				char	   *p;
 
@@ -1777,7 +1777,6 @@ str_initcap(const char *buff, size_t nbytes, Oid collid)
 	{
 		result = asc_initcap(buff, nbytes);
 	}
-#ifdef USE_WIDE_UPPER_LOWER
 	else
 	{
 		pg_locale_t mylocale = 0;
@@ -1815,6 +1814,7 @@ str_initcap(const char *buff, size_t nbytes, Oid collid)
 		else
 #endif
 		{
+#ifdef USE_WIDE_UPPER_LOWER
 			if (pg_database_encoding_max_length() > 1)
 			{
 				wchar_t    *workspace;
@@ -1864,8 +1864,8 @@ str_initcap(const char *buff, size_t nbytes, Oid collid)
 				wchar2char(result, workspace, result_size, mylocale);
 				pfree(workspace);
 			}
-#endif							/* USE_WIDE_UPPER_LOWER */
 			else
+#endif							/* USE_WIDE_UPPER_LOWER */
 			{
 				char	   *p;
 
-- 
2.14.1

